@@ -1,15 +1,22 @@
 import pandas as pd
 import numpy as np
 import datetime as dt
-import os as os
-import openpyxl as xl
-import pyodbc as odbc
 import humanfriendly as hf
 import platform as pl
+import openpyxl as xl
+import os
+import time
+import json
+import pymssql
 import sys
-from google.cloud.bigquery import Client, LoadJobConfig, DatasetReference
+
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
+from smtplib import SMTP, SMTPException
+from google.cloud.bigquery import Client, LoadJobConfig, DatasetReference, TableReference
 from google.cloud.bigquery import SchemaField as sf
 from google.oauth2 import service_account
+from dateutil.relativedelta import relativedelta
 
 from CsPy_Uploading.classes import BaseJob
 from CsPy_Uploading.classes import JobSettings
@@ -75,5 +82,5 @@ Functions:
 Misc variables:
 
     __version__
-    1.0.2
+    1.0.4
 """
\ No newline at end of file
