@@ -20,8 +20,6 @@ from CsPy_Uploading.functions import left
 from CsPy_Uploading.functions import right
 
 
-# TODO: Maybe add data cleaning within the download job
-
 class BaseJob:
     """
     Desc:
@@ -95,6 +93,7 @@ class BaseJob:
         # Initialisation
         self.start_time = dt.datetime.now()
         self.temp_set_logging = set_logging
+        self.version = '1.0.4'
         self.run_error = False
         self.sys_exit = False
         self.thg_log()
@@ -186,7 +185,7 @@ class BaseJob:
             &&&&&&&@               &&&&&&&%           &&&&&&&.         &&&&&&&&&&&&&&&&&&&&&&&*    
             &&&&&&&@               &&&&&&&%           &&&&&&&.            &&&&&&&&&&&&&&&&@&.       
      
-    CsPy Uploading Python Package Version: 1.0.2""")
+    CsPy Uploading Python Package Version: {}""".format(self.version))
             print('=' * 99)
 
     def insert_line(self):
@@ -227,7 +226,7 @@ class BaseJob:
             file = sys.modules['__main__'].__file__
             directory_name, file_name = os.path.split(os.path.abspath(file))
             self.job_details['Location On VM'] = str(directory_name)
-            self.job_details['Script Name'] = right(file, (len(file) - file.rfind('/')) - 1)
+            self.job_details['Script Name'] = file_name
 
         elif left(computer_node, 5) == 'UK-LT' or left(computer_node, 3) == 'THG' or left(computer_node,
                                                                                           7) == 'DESKTOP':
@@ -548,8 +547,7 @@ class BaseJob:
         if self.run_error:
             if not self.setting.testing and self.vm_status and self.use_account:
                 sender = self.account.info['data_team_vm_email']
-                receiver = '{0}; {1}; {2}'.format(
-                    self.account.info['data_team_vm_email'],
+                receiver = '{0}; {1}'.format(
                     self.account.info['data_team_email'],
                     self.account.info['email']
                 )
@@ -560,24 +558,26 @@ class BaseJob:
                 msg['Subject'] = 'VM Script: {} Failed to Run.'.format(self.job_details['Script Name'])
 
                 message = """
-                    Time Ran: {0}
-                    The Script located at: {1}{2}
-                    The Script failed at: {3} - {4}
-                    
-                    Error Message: {5}
-                    Error Solution: {6}
-                    
-                    For Further Details Please Read The Script Logs On The VM
-                    """.format(self.job_details['Run Date'],
-                               self.job_details['Location On VM'],
-                               self.job_details['Script Name'],
-                               self.job_details['Job Portion'],
-                               self.job_details['Job Progress'],
-                               self.job_details['Error Message'],
-                               self.job_details['Solution']
-                               )
+                <p><strong>Time Ran:</strong> {0} <br>
+                <strong>Script Owner:</strong> {1} <br><br>
+                <strong>The Script located at:</strong> {2}\\{3} <br>
+                <strong>The Script failed at:</strong> {4} - {5} <br><br>
+                <strong>Error Message:</strong> {6} <br>
+                <strong>Error Solution:</strong> {7} <br><br>
+                For Further Details Please Read The Script Logs On The VM <br>
+                <strong>CsPy Version: {8}</p>
+                """.format(self.job_details['Run Date'],
+                           self.account.info['first_name'] + ' ' + self.account.info['surname'],
+                           self.job_details['Location On VM'],
+                           self.job_details['Script Name'],
+                           self.job_details['Job Portion'],
+                           self.job_details['Job Progress'],
+                           self.job_details['Error Message'],
+                           self.job_details['Solution'],
+                           self.version
+                           )
 
-                msg.attach(MIMEText(message, 'plain'))
+                msg.attach(MIMEText(message, 'HTML'))
 
                 with SMTP(host="fortimail.gslb.thehut.local", port=25) as smtp:
                     try:
@@ -1289,6 +1289,10 @@ class UploadJob(BaseJob):
         try:
             self.job_details['Job Portion'] = 'Running Upload Job'
             self.job_details['Job Status'] = 'Ran Successfully'
+            self.job_details['Error'] = ''
+            self.run_error = False
+            self.sys_exit = False
+
             self.progress_update('Creating Upload Files', print_line=True, print_value=True)
             self.create_upload_files()
             self.progress_update('Uploading to Big query', print_line=True, print_value=True)
@@ -1401,7 +1405,7 @@ class UploadJob(BaseJob):
 
             self.job_details['Runtime'] = (dt.datetime.now() - self.start_time).total_seconds()
 
-            if self.job_details['Error'] == '':
+            if self.job_details['Error'] != '':
                 self.send_email()
 
             if self.vm_status:
@@ -1564,8 +1568,7 @@ class UploadJob(BaseJob):
         self.job_details['Job Status'] = 'Ran Unsuccessfully'
         if not self.setting.testing and self.vm_status and self.use_account:
             sender = self.account.info['data_team_vm_email']
-            receiver = '{0}; {1}; {2}'.format(
-                self.account.info['data_team_vm_email'],
+            receiver = '{0}; {1}'.format(
                 self.account.info['data_team_email'],
                 self.account.info['email']
             )
@@ -1579,18 +1582,24 @@ class UploadJob(BaseJob):
                     self.job_details['GA Error'] = 'No GA Error'
 
             message = """
-                Time Ran: {0}
-                The Script located at: {1}{2}
-                The Script failed at: {3}
-                Failed to run successfully due to python error message: {4}
-                Failed to run successfully due to GA error message: {5}
-                """.format(self.job_details['Run Date'],
-                           self.job_details['Location On VM'],
-                           self.job_details['Script Name'],
-                           self.job_details['Job Progress'],
-                           self.job_details['Error'],
-                           self.job_details['GA Error']
-                           )
+            <p><strong>Time Ran:</strong> {0} <br>
+            <strong>Script Owner:</strong> {1} <br><br>
+            <strong>The Script located at:</strong> {2}\\{3} <br>
+            <strong>The Script failed at:</strong> {4} - {5} <br><br>
+            <strong>Error Message:</strong> {6} <br>
+            <strong>BQ Error Message:</strong> {7} <br><br>
+            For Further Details Please Read The Script Logs On The VM <br>
+            <strong>CsPy Version: {8}</p>
+            """.format(self.job_details['Run Date'],
+                       self.account.info['first_name'] + ' ' + self.account.info['surname'],
+                       self.job_details['Location On VM'],
+                       self.job_details['Script Name'],
+                       self.job_details['Job Portion'],
+                       self.job_details['Job Progress'],
+                       self.job_details['Error'],
+                       self.job_details['GA Error'],
+                       self.version
+                       )
 
             msg.attach(MIMEText(message, 'plain'))
 
@@ -1601,6 +1610,9 @@ class UploadJob(BaseJob):
                 except SMTPException as error:
                     self.log('Failed Script Email not sent Error: {0}.'.format(error))
 
+        else:
+            self.log("Failed Email Alert Not Sent. Only Available On The VM Whilst Using Accounts")
+
 
 class DownloadJob(BaseJob):
     """
@@ -1812,6 +1824,9 @@ class DownloadJob(BaseJob):
         """
         try:
             self.job_details['Job Portion'] = 'Running Download Job'
+            self.job_details['Error'] = ''
+            self.run_error = False
+            self.sys_exit = False
             self.progress_update('Creating Download Files', print_line=True, print_value=True)
             if self.output_data_type is None:
                 self.log("output_data_type Not Supplied Using Default Out Of CSV")
@@ -1968,6 +1983,7 @@ class Account:
                     if self.info['data_team_id'] == i["data_team_id"]:
                         self.log("Data Team VM Info Found")
                         if i["complete"] == 1:
+                            self.log('Updated VM Team Info')
                             self.info['key_folder_path'] = i["key_path_folder"]
                             self.info['data_team_vm_email'] = i["vm_email"]
                             break
